# LunesPy

**The [old version](https://github.com/lunes-platform/lunespy/blob/main/deprecated) is being discontinued, but it can still be used at your own and risk.**

Library for communication with nodes in mainnet or testnet of the lunes-blockchain network
Allows the automation of **sending assets**, **issue end reissue tokens**, **lease** and **create new wallet**.


## [What's new?](https://github.com/lunes-platform/lunespy/blob/main/CHANGELOG.md)


## [How to use LunesPy?](https://blockchain.lunes.io/telescope/docs/sdk/getting_started)


## [Want to contribute to LunesPy?](https://github.com/lunes-platform/lunespy/blob/main/CONTRIBUTING.md)


## Contributors

Thanks to the following people who have contributed to this project:

* [olivmath](https://github.com/olivmath)
* [marcoslkz](https://github.com/marcoslkz)
* [VanJustin](https://github.com/VanJustin)
* [xonfps](https://github.com/xonfps)

## Contact

If you want to contact me you can reach me at <development@lunes.io>.

## License

[Apache License Version 2.0](https://github.com/lunes-platform/lunespy/blob/main/LICENSE).
